==> haskell-hls-explicit-record-fields-plugin-1.0.0.0-160-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-record-fields-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-explicit-record-fields-plugin
version:              1.0.0.0
visibility:           public
id:
    hls-explicit-record-fields-plugin-1.0.0.0-9ASOFuR5UaeF3inZAuBxzq

key:
    hls-explicit-record-fields-plugin-1.0.0.0-9ASOFuR5UaeF3inZAuBxzq

license:              BSD-3-Clause
maintainer:           berk.ozkutuk@tweag.io
author:               Berk Ozkutuk
synopsis:             Explicit record fields plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  ab10f2babf5df713fb317c0aac474b7f
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitFields
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-explicit-record-fields-plugin-1.0.0.0

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-explicit-record-fields-plugin-1.0.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-record-fields-plugin
hs-libraries:
    HShls-explicit-record-fields-plugin-1.0.0.0-9ASOFuR5UaeF3inZAuBxzq

depends:
    base-4.16.4.0 containers-0.6.5.1 ghc-boot-th-9.2.8
    ghcide-1.9.1.0-HwAkVTDd37EFvNbRQNs88T
    hls-graph-1.9.0.0-4nTvQprVee21P1DngyVSFV
    hls-plugin-api-1.6.0.0-6Ebop0G4HfEC83Y5bnhsUu
    lens-5.2.3-Lr9JV2q3Rgv6Xn7f42cFjs
    lsp-1.6.0.0-1JAbQDnc0SK1hycTz4LLrJ
    syb-0.7.2.4-I6Nnpf8cvJCKAwaV0JIT6f text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-Kaqz4YtssULDpEsD0of7Qa

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-record-fields-plugin/html/hls-explicit-record-fields-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-explicit-record-fields-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-explicit-record-fields-plugin-1.0.1.0-2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-record-fields-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-explicit-record-fields-plugin
version:              1.0.1.0
visibility:           public
id:
    hls-explicit-record-fields-plugin-1.0.1.0-CqhFEJCcXLnFoUgAyflr04

key:
    hls-explicit-record-fields-plugin-1.0.1.0-CqhFEJCcXLnFoUgAyflr04

license:              BSD-3-Clause
maintainer:           berk.ozkutuk@tweag.io
author:               Berk Ozkutuk
synopsis:             Explicit record fields plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  228489ba0a38c5937972424e20bb5a03
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitFields
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-explicit-record-fields-plugin-1.0.1.0

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-explicit-record-fields-plugin-1.0.1.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-record-fields-plugin
hs-libraries:
    HShls-explicit-record-fields-plugin-1.0.1.0-CqhFEJCcXLnFoUgAyflr04

depends:
    base-4.16.4.0 containers-0.6.5.1 ghc-boot-th-9.2.8
    ghcide-1.10.0.0-42asgJmBwLYDXfQ3kee4Wu
    hls-graph-1.9.0.0-7y2pZvkYmIwHHyfFLNsbki
    hls-plugin-api-1.6.0.0-GBhVrEAXY9G7a8rlmXAPNi
    lens-5.2.3-JhnKgAx9k76Jin0xTqnLw0
    lsp-1.6.0.0-3mgfXrOs4nYBY8raCTSUiO
    syb-0.7.2.4-4iiIjHgm67gJA1HTgFmr8s text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-record-fields-plugin/html/hls-explicit-record-fields-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-explicit-record-fields-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
